hammett
=======

hammett is a fast python test runner that is largely compatible with pytest.

It does not support class based tests at this time though.


Usage
------

First install: :code:`pip install hammett`

Then run hammett: :code:`python -m hammett`

Hopefully it will run your entire test suite!

hammett works with some pytest plugins, most notably pytest-django, at least for some projects.


License
-------

BSD
